Description: We sell windshield sun shades/shields for the 2016 Acura ILX (w/ Sensor). Heatshield protects against heat damage, and keeps the inside of parked cars cooler. Side, top, and rear window shades may be available.

Internet Explorer users: There have been issues during checkout. Please use an alternative browser.

- catalog
- cart (0)
- FAQs
- about us
- contact us
- feedback

Our Catalog » Sun Shades for Acura »

# Sun Shades for 2016 Acura ILX (w/ Sensor)

Sun protection product(s) for the 2016 Acura ILX (w/ Sensor) are listed below.

Heatshields to add for next price break ($35.00):

2

NOTE: You may need to scroll to the right to view entire table.

make | model | year | part no. | color | price | qty | add to cart
--- | --- | --- | --- | --- | --- | --- | ---
Acura | ILX (w/ Sensor) | 2016 | 1587W (windshield) |  | $39.95 |  |
Acura | ILX (w/ Sensor) | 2016 | 1587R (rear) |  | $39.95 |  |
Acura | ILX (w/ Sensor) | 2016 | 1587S (side) |  | $39.95 |  |

# photos

Unfortunately, we do not have any photos of our heatshields on this car model. But fear not! The products listed are still custom-fit to the car. Below are some generic photos of our Heatshields.

# find other cars

Use the drop-down menus below to go to other car pages.

year
manufacturer
model